@@ -1,4 +1,5 @@
-from flask import jsonify, request
+from flask import jsonify, request, Response
+from sqlalchemy.orm import Session
 
 from flexget.api import APIResource, api
 from flexget.api.app import BadRequest, base_message_schema, success_response
@@ -29,8 +30,9 @@ input_schema = api.schema_model('db_schema', ObjectsContainer.database_input_obj
 class DBOperation(APIResource):
     @api.validate(input_schema)
     @api.response(200, model=base_message_schema)
-    def post(self, session=None):
+    def post(self, session: Session = None) -> Response:
         """Perform DB operations"""
+        msg = ''
         data = request.json
         operation = data['operation']
         if operation == 'cleanup':
@@ -44,19 +46,19 @@ class DBOperation(APIResource):
             plugin_name = data.get('plugin_name')
             if not plugin_name:
                 raise BadRequest(
-                    '\'plugin_name\' attribute must be used when trying to reset plugin'
+                    "'plugin_name' attribute must be used when trying to reset plugin"
                 )
             try:
                 reset_schema(plugin_name)
-                msg = 'Plugin {} DB reset was successful'.format(plugin_name)
+                msg = f'Plugin {plugin_name} DB reset was successful'
             except ValueError:
-                raise BadRequest('The plugin {} has no stored schema to reset'.format(plugin_name))
+                raise BadRequest(f'The plugin {plugin_name} has no stored schema to reset')
         return success_response(msg)
 
 
 @db_api.route('/plugins/')
 class DBCleanup(APIResource):
     @api.response(200, model=plugins_schema)
-    def get(self, session=None):
+    def get(self, session: Session = None) -> Response:
         """List resettable DB plugins"""
         return jsonify(sorted(list(plugin_schemas)))
