@@ -2,10 +2,11 @@ import datetime
 import os
 import re
 from collections import defaultdict
-from typing import Any, Callable, Dict, Optional, Union
+from typing import Any, Callable, Dict, List, Match, Optional, Pattern, Union
 from urllib.parse import parse_qsl, urlparse
 
 import jsonschema
+from jsonschema import ValidationError
 from jsonschema.compat import int_types, str_types
 from loguru import logger
 
@@ -16,10 +17,18 @@ from flexget.utils.tools import parse_episode_identifier, parse_timedelta
 
 logger = logger.bind(name='config_schema')
 
-schema_paths = {}
 CURRENT_SCHEMA_VERSION = 'http://json-schema.org/draft-04/schema#'
 # Type hint for json schemas. (If we upgrade to a newer json schema version, the type might allow more than dicts.)
 JsonSchema = Dict[str, Any]
+schema_paths: Dict[str, Union[JsonSchema, Callable[..., JsonSchema]]] = {}
+
+
+class ConfigValidationError(ValidationError):
+    json_pointer: str
+
+
+class ConfigError(ValueError):
+    errors: List[ConfigValidationError]
 
 
 # TODO: Rethink how config key and schema registration work
@@ -38,7 +47,7 @@ _root_config_schema: Optional[JsonSchema] = None
 
 
 def register_config_key(key: str, schema: JsonSchema, required: bool = False):
-    """ Registers a valid root level key for the config.
+    """Registers a valid root level key for the config.
 
     :param string key:
       Name of the root level key being registered.
@@ -77,7 +86,8 @@ def one_or_more(schema: JsonSchema, unique_items: bool = False) -> JsonSchema:
     """
 
     schema.setdefault('title', 'single value')
-    return {
+    default = schema.pop('default', None)
+    result = {
         'oneOf': [
             {
                 'title': 'multiple values',
@@ -89,6 +99,9 @@ def one_or_more(schema: JsonSchema, unique_items: bool = False) -> JsonSchema:
             schema,
         ]
     }
+    if default:
+        result['default'] = default
+    return result
 
 
 def resolve_ref(uri: str) -> JsonSchema:
@@ -105,7 +118,9 @@ def resolve_ref(uri: str) -> JsonSchema:
     raise jsonschema.RefResolutionError("%s could not be resolved" % uri)
 
 
-def process_config(config: Any, schema: Optional[JsonSchema] = None, set_defaults: bool = True):
+def process_config(
+    config: Any, schema: Optional[JsonSchema] = None, set_defaults: bool = True
+) -> List[ConfigValidationError]:
     """
     Validates the config, and sets defaults within it if `set_defaults` is set.
     If schema is not given, uses the root config schema.
@@ -120,7 +135,7 @@ def process_config(config: Any, schema: Optional[JsonSchema] = None, set_default
     if set_defaults:
         validator.VALIDATORS['properties'] = validate_properties_w_defaults
     try:
-        errors = list(validator.iter_errors(config))
+        errors: List[ValidationError] = list(validator.iter_errors(config))
     finally:
         validator.VALIDATORS['properties'] = jsonschema.Draft4Validator.VALIDATORS['properties']
     # Customize the error messages
@@ -199,35 +214,35 @@ def is_quality_req(instance):
 
 
 @format_checker.checks('time', raises=ValueError)
-def is_time(time_string):
+def is_time(time_string) -> bool:
     if not isinstance(time_string, str_types):
         return True
     return parse_time(time_string) is not None
 
 
 @format_checker.checks('interval', raises=ValueError)
-def is_interval(interval_string):
+def is_interval(interval_string) -> bool:
     if not isinstance(interval_string, str_types):
         return True
     return parse_interval(interval_string) is not None
 
 
 @format_checker.checks('size', raises=ValueError)
-def is_size(size_string):
+def is_size(size_string) -> bool:
     if not isinstance(size_string, (str_types, int_types)):
         return True
     return parse_size(size_string) is not None
 
 
 @format_checker.checks('percent', raises=ValueError)
-def is_percent(percent_string):
+def is_percent(percent_string) -> bool:
     if not isinstance(percent_string, str_types):
         return True
     return parse_percent(percent_string) is not None
 
 
 @format_checker.checks('regex', raises=ValueError)
-def is_regex(instance):
+def is_regex(instance) -> Union[bool, Pattern]:
     if not isinstance(instance, str_types):
         return True
     try:
@@ -237,7 +252,7 @@ def is_regex(instance):
 
 
 @format_checker.checks('file', raises=ValueError)
-def is_file(instance):
+def is_file(instance) -> bool:
     if not isinstance(instance, str_types):
         return True
     if os.path.isfile(os.path.expanduser(instance)):
@@ -246,7 +261,7 @@ def is_file(instance):
 
 
 @format_checker.checks('path', raises=ValueError)
-def is_path(instance):
+def is_path(instance) -> bool:
     if not isinstance(instance, str_types):
         return True
     # Only validate the part of the path before the first identifier to be replaced
@@ -261,9 +276,12 @@ def is_path(instance):
 
 # TODO: jsonschema has a format checker for uri if rfc3987 is installed, perhaps we should use that
 @format_checker.checks('url')
-def is_url(instance):
+def is_url(instance) -> Union[None, bool, Match]:
     if not isinstance(instance, str_types):
         return True
+    # Allow looser validation if this appears to start with jinja
+    if instance.startswith('{{') or instance.startswith('{%'):
+        return True
     regexp = (
         '('
         + '|'.join(['ftp', 'http', 'https', 'file', 'udp', 'socks5h?'])
@@ -273,7 +291,7 @@ def is_url(instance):
 
 
 @format_checker.checks('episode_identifier', raises=ValueError)
-def is_episode_identifier(instance):
+def is_episode_identifier(instance) -> bool:
     if not isinstance(instance, (str_types, int)):
         return True
     return parse_episode_identifier(instance) is not None
@@ -287,13 +305,13 @@ def is_episode_or_season_id(instance):
 
 
 @format_checker.checks('file_template', raises=ValueError)
-def is_valid_template(instance):
+def is_valid_template(instance) -> bool:
     if not isinstance(instance, str_types):
         return True
     return get_template(instance) is not None
 
 
-def set_error_message(error):
+def set_error_message(error: jsonschema.ValidationError) -> None:
     """
     Create user facing error message from a :class:`jsonschema.ValidationError` `error`
 
@@ -301,19 +319,19 @@ def set_error_message(error):
     # First, replace default error messages with our custom ones
     if error.validator == 'type':
         if isinstance(error.validator_value, str):
-            valid_types = [error.validator_value]
+            valid_types_list = [error.validator_value]
         else:
-            valid_types = list(error.validator_value)
+            valid_types_list = list(error.validator_value)
         # Replace some types with more pythony ones
         replace = {'object': 'dict', 'array': 'list'}
-        valid_types = [replace.get(t, t) for t in valid_types]
+        valid_types_list = [replace.get(t, t) for t in valid_types_list]
         # Make valid_types into an english list, with commas and 'or'
-        valid_types = ', '.join(valid_types[:-2] + ['']) + ' or '.join(valid_types[-2:])
+        valid_types = ', '.join(valid_types_list[:-2] + ['']) + ' or '.join(valid_types_list[-2:])
         if isinstance(error.instance, dict):
-            error.message = 'Got a dict, expected: %s' % valid_types
+            error.message = f'Got a dict, expected: {valid_types}'
         if isinstance(error.instance, list):
-            error.message = 'Got a list, expected: %s' % valid_types
-        error.message = 'Got `%s`, expected: %s' % (error.instance, valid_types)
+            error.message = f'Got a list, expected: {valid_types}'
+        error.message = f'Got `{error.instance}`, expected: {valid_types}'
     elif error.validator == 'format':
         if error.cause:
             error.message = str(error.cause)
