@@ -1,15 +1,12 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
-import logging
-
 from colorclass.toggles import disable_all_colors
+from loguru import logger
+
 from flexget import options
 from flexget.event import event
 from flexget.plugin import get_plugins
-from flexget.terminal import TerminalTable, TerminalTableError, table_parser, console, colorize
+from flexget.terminal import TerminalTable, TerminalTableError, colorize, console, table_parser
 
-log = logging.getLogger('plugins')
+logger = logger.bind(name='plugins')
 
 
 def plugins_summary(manager, options):
@@ -51,8 +48,12 @@ def plugins_summary(manager, options):
 
 @event('options.register')
 def register_parser_arguments():
-    parser = options.register_command('plugins', plugins_summary, help='Print registered plugin summaries',
-                                      parents=[table_parser])
+    parser = options.register_command(
+        'plugins',
+        plugins_summary,
+        help='Print registered plugin summaries',
+        parents=[table_parser],
+    )
     parser.add_argument('--interface', help='Show plugins belonging to this interface')
     parser.add_argument('--phase', help='Show plugins that act on this phase')
     parser.add_argument('--builtins', action='store_true', help='Show just builtin plugins')
