@@ -1,23 +1,23 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-from past.builtins import basestring
+from pathlib import Path
 
-import logging
-
-from path import Path
+from loguru import logger
 
 from flexget import plugin
-from flexget.event import event
 from flexget.config_schema import one_or_more
+from flexget.event import event
 from flexget.utils.log import log_once
 from flexget.utils.template import RenderError
-from flexget.plugins.parsers import ParseWarning
-from flexget.plugin import get_plugin_by_name
 
-log = logging.getLogger('exists_series')
+try:
+    # NOTE: Importing other plugins is discouraged!
+    from flexget.components.parsing import parsers as plugin_parsers
+except ImportError:
+    raise plugin.DependencyError(issued_by=__name__, missing='parsers')
+
+logger = logger.bind(name='exists_series')
 
 
-class FilterExistsSeries(object):
+class FilterExistsSeries:
     """
     Intelligent series aware exists rejecting.
 
@@ -33,11 +33,14 @@ class FilterExistsSeries(object):
                 'type': 'object',
                 'properties': {
                     'path': one_or_more({'type': 'string', 'format': 'path'}),
-                    'allow_different_qualities': {'enum': ['better', True, False], 'default': False}
+                    'allow_different_qualities': {
+                        'enum': ['better', True, False],
+                        'default': False,
+                    },
                 },
                 'required': ['path'],
-                'additionalProperties': False
-            }
+                'additionalProperties': False,
+            },
         ]
     }
 
@@ -46,14 +49,14 @@ class FilterExistsSeries(object):
         if not isinstance(config, dict):
             config = {'path': config}
         # if only a single path is passed turn it into a 1 element list
-        if isinstance(config['path'], basestring):
+        if isinstance(config['path'], str):
             config['path'] = [config['path']]
         return config
 
     @plugin.priority(-1)
     def on_task_filter(self, task, config):
         if not task.accepted:
-            log.debug('Scanning not needed')
+            logger.debug('Scanning not needed')
             return
         config = self.prepare_config(config)
         accepted_series = {}
@@ -66,11 +69,13 @@ class FilterExistsSeries(object):
                         try:
                             paths.add(entry.render(folder))
                         except RenderError as e:
-                            log.error('Error rendering path `%s`: %s', folder, e)
+                            logger.error('Error rendering path `{}`: {}', folder, e)
                 else:
-                    log.debug('entry %s series_parser invalid', entry['title'])
+                    logger.debug('entry {} series_parser invalid', entry['title'])
         if not accepted_series:
-            log.warning('No accepted entries have series information. exists_series cannot filter them')
+            logger.warning(
+                'No accepted entries have series information. exists_series cannot filter them'
+            )
             return
 
         # scan through
@@ -80,44 +85,52 @@ class FilterExistsSeries(object):
             series_parser = accepted_series[series][0]['series_parser']
             for folder in paths:
                 folder = Path(folder).expanduser()
-                if not folder.isdir():
-                    log.warning('Directory %s does not exist', folder)
+                if not folder.is_dir():
+                    logger.warning('Directory {} does not exist', folder)
                     continue
 
-                for filename in folder.walk(errors='ignore'):
+                for filename in folder.iterdir():
                     # run parser on filename data
                     try:
-                        disk_parser = get_plugin_by_name('parsing').instance.parse_series(data=filename.name,
-                                                                                          name=series_parser.name)
-                    except ParseWarning as pw:
+                        disk_parser = plugin.get('parsing', self).parse_series(
+                            data=filename.name, name=series_parser.name
+                        )
+                    except plugin_parsers.ParseWarning as pw:
                         disk_parser = pw.parsed
-                        log_once(pw.value, logger=log)
+                        log_once(pw.value, logger=logger)
                     if disk_parser.valid:
-                        log.debug('name %s is same series as %s', filename.name, series)
-                        log.debug('disk_parser.identifier = %s', disk_parser.identifier)
-                        log.debug('disk_parser.quality = %s', disk_parser.quality)
-                        log.debug('disk_parser.proper_count = %s', disk_parser.proper_count)
+                        logger.debug('name {} is same series as {}', filename.name, series)
+                        logger.debug('disk_parser.identifier = {}', disk_parser.identifier)
+                        logger.debug('disk_parser.quality = {}', disk_parser.quality)
+                        logger.debug('disk_parser.proper_count = {}', disk_parser.proper_count)
 
                         for entry in accepted_series[series]:
-                            log.debug('series_parser.identifier = %s', entry['series_parser'].identifier)
+                            logger.debug(
+                                'series_parser.identifier = {}', entry['series_parser'].identifier
+                            )
                             if disk_parser.identifier != entry['series_parser'].identifier:
-                                log.trace('wrong identifier')
+                                logger.trace('wrong identifier')
                                 continue
-                            log.debug('series_parser.quality = %s', entry['series_parser'].quality)
+                            logger.debug(
+                                'series_parser.quality = {}', entry['series_parser'].quality
+                            )
                             if config.get('allow_different_qualities') == 'better':
                                 if entry['series_parser'].quality > disk_parser.quality:
-                                    log.trace('better quality')
+                                    logger.trace('better quality')
                                     continue
                             elif config.get('allow_different_qualities'):
                                 if disk_parser.quality != entry['series_parser'].quality:
-                                    log.trace('wrong quality')
+                                    logger.trace('wrong quality')
                                     continue
-                            log.debug('entry parser.proper_count = %s', entry['series_parser'].proper_count)
+                            logger.debug(
+                                'entry parser.proper_count = {}',
+                                entry['series_parser'].proper_count,
+                            )
                             if disk_parser.proper_count >= entry['series_parser'].proper_count:
-                                entry.reject('proper already exists')
+                                entry.reject('episode already exists')
                                 continue
                             else:
-                                log.trace('new one is better proper, allowing')
+                                logger.trace('new one is better proper, allowing')
                                 continue
 
 
