@@ -1,22 +1,23 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-
-import logging
-
 from bs4 import NavigableString
+from loguru import logger
 from requests import RequestException
 
 from flexget import plugin
 from flexget.entry import Entry
 from flexget.event import event
 from flexget.utils.cached_input import cached
-from flexget.utils.imdb import extract_id
 from flexget.utils.soup import get_soup
 
-log = logging.getLogger('sceper')
+try:
+    # NOTE: Importing other plugins is discouraged!
+    from flexget.components.imdb.utils import extract_id
+except ImportError:
+    raise plugin.DependencyError(issued_by=__name__, missing='imdb')
+
+logger = logger.bind(name='sceper')
 
 
-class InputSceper(object):
+class InputSceper:
     """
     Uses sceper.ws category url as input.
 
@@ -41,11 +42,11 @@ class InputSceper(object):
             release = {}
             title = entry.find('h2')
             if not title:
-                log.debug('No h2 entrytitle')
+                logger.debug('No h2 entrytitle')
                 continue
             release['title'] = title.a.contents[0].strip()
 
-            log.debug('Processing title %s' % (release['title']))
+            logger.debug('Processing title {}', release['title'])
 
             for link in entry.find_all('a'):
                 # no content in the link
@@ -61,35 +62,39 @@ class InputSceper(object):
                     link_href = link['href']
                 else:
                     continue
-                log.debug('found link %s -> %s' % (link_name, link_href))
+                logger.debug('found link {} -> {}', link_name, link_href)
                 # handle imdb link
                 if link_name.lower() == 'imdb':
-                    log.debug('found imdb link %s' % link_href)
+                    logger.debug('found imdb link {}', link_href)
                     release['imdb_id'] = extract_id(link_href)
 
                 # test if entry with this url would be rewritable by known plugins (ie. downloadable)
                 temp = {}
                 temp['title'] = release['title']
                 temp['url'] = link_href
-                urlrewriting = plugin.get_plugin_by_name('urlrewriting')
-                if urlrewriting['instance'].url_rewritable(task, temp):
+                urlrewriting = plugin.get('urlrewriting', self)
+                if urlrewriting.url_rewritable(task, temp):
                     release['url'] = link_href
-                    log.trace('--> accepting %s (resolvable)' % link_href)
+                    logger.trace('--> accepting {} (resolvable)', link_href)
                 else:
-                    log.trace('<-- ignoring %s (non-resolvable)' % link_href)
+                    logger.trace('<-- ignoring {} (non-resolvable)', link_href)
 
             # reject if no torrent link
             if 'url' not in release:
                 from flexget.utils.log import log_once
-                log_once('%s skipped due to missing or unsupported (unresolvable) download link' % (release['title']),
-                         log)
+
+                log_once(
+                    '%s skipped due to missing or unsupported (unresolvable) download link'
+                    % (release['title']),
+                    logger,
+                )
             else:
                 releases.append(release)
 
         return releases
 
     @cached('sceper')
-    @plugin.internet(log)
+    @plugin.internet(logger)
     def on_task_input(self, task, config):
         releases = self.parse_site(config, task)
         return [Entry(release) for release in releases]
