@@ -5,7 +5,9 @@ Plugins can just import the methods from this module.
 Also allows date and datetime objects to be encoded/decoded.
 """
 import datetime
-from collections import Mapping, Iterable
+from collections.abc import Iterable, Mapping
+from contextlib import suppress
+from typing import Union, Any
 
 from flexget.plugin import DependencyError
 
@@ -13,11 +15,11 @@ try:
     import simplejson as json
 except ImportError:
     try:
-        import json
+        import json  # type: ignore  # python/mypy#1153
     except ImportError:
         try:
             # Google Appengine offers simplejson via django
-            from django.utils import simplejson as json
+            from django.utils import simplejson as json  # type: ignore
         except ImportError:
             raise DependencyError(missing='simplejson')
 
@@ -37,15 +39,13 @@ class DTDecoder(json.JSONDecoder):
             try:
                 return datetime.datetime.strptime(dt_str, ISO8601_FMT)
             except (ValueError, TypeError):
-                try:
+                with suppress(ValueError, TypeError):
                     return datetime.datetime.strptime(dt_str, DATE_FMT)
-                except (ValueError, TypeError):
-                    pass
 
         return super().decode(obj, **kwargs)
 
 
-def _datetime_encoder(obj):
+def _datetime_encoder(obj: Union[datetime.datetime, datetime.date]) -> str:
     if isinstance(obj, datetime.datetime):
         return obj.strftime(ISO8601_FMT)
     elif isinstance(obj, datetime.date):
@@ -53,7 +53,7 @@ def _datetime_encoder(obj):
     raise TypeError
 
 
-def _datetime_decoder(dict_):
+def _datetime_decoder(dict_: dict) -> dict:
     for key, value in dict_.items():
         # The built-in `json` library will `unicode` strings, except for empty strings. patch this for
         # consistency so that `unicode` is always returned.
@@ -65,38 +65,35 @@ def _datetime_decoder(dict_):
             datetime_obj = datetime.datetime.strptime(value, ISO8601_FMT)
             dict_[key] = datetime_obj
         except (ValueError, TypeError):
-            try:
+            with suppress(ValueError, TypeError):
                 date_obj = datetime.datetime.strptime(value, DATE_FMT)
                 dict_[key] = date_obj.date()
-            except (ValueError, TypeError):
-                continue
 
     return dict_
 
 
-def _empty_unicode_decoder(dict_):
+def _empty_unicode_decoder(dict_: dict) -> dict:
     for key, value in dict_.items():
         # The built-in `json` library will `unicode` strings, except for empty strings. patch this for
         # consistency so that `unicode` is always returned.
         if value == b'':
             dict_[key] = ''
-            continue
     return dict_
 
 
-def dumps(*args, **kwargs):
+def dumps(*args, **kwargs) -> str:
     if kwargs.pop('encode_datetime', False):
         kwargs['default'] = _datetime_encoder
     return json.dumps(*args, **kwargs)
 
 
-def dump(*args, **kwargs):
+def dump(*args, **kwargs) -> None:
     if kwargs.pop('encode_datetime', False):
         kwargs['default'] = _datetime_encoder
     return json.dump(*args, **kwargs)
 
 
-def loads(*args, **kwargs):
+def loads(*args, **kwargs) -> Any:
     """
     :param bool decode_datetime: If `True`, dates in ISO8601 format will be deserialized to :class:`datetime.datetime`
       objects.
@@ -109,7 +106,7 @@ def loads(*args, **kwargs):
     return json.loads(*args, **kwargs)
 
 
-def load(*args, **kwargs):
+def load(*args, **kwargs) -> Any:
     """
     :param bool decode_datetime: If `True`, dates in ISO8601 format will be deserialized to :class:`datetime.datetime`
       objects.
@@ -122,7 +119,7 @@ def load(*args, **kwargs):
     return json.load(*args, **kwargs)
 
 
-def coerce(obj):
+def coerce(obj) -> Union[str, int, float, bool, dict, list, None]:
     """
     Coerce a data structure to a JSON serializable form.
 
